@@ -47,5 +47,12 @@ func LoadConfig(yamlfile string) (*Config, error) {
 		config.Languages = &languages
 	}
 	config.Filename = yamlfile
+	for _, v := range *config.Languages {
+		for _, l := range v {
+			if l.HoverChars == "" {
+				l.HoverChars = "_"
+			}
+		}
+	}
 	return &config, nil
 }
