@@ -7,7 +7,7 @@ import (
 	"github.com/sourcegraph/jsonrpc2"
 )
 
-func (h *langHandler) handleTextDocumentDidSave(ctx context.Context, conn *jsonrpc2.Conn, req *jsonrpc2.Request) (result interface{}, err error) {
+func (h *langHandler) handleTextDocumentDidSave(_ context.Context, _ *jsonrpc2.Conn, req *jsonrpc2.Request) (result any, err error) {
 	if req.Params == nil {
 		return nil, &jsonrpc2.Error{Code: jsonrpc2.CodeInvalidParams}
 	}
@@ -18,7 +18,7 @@ func (h *langHandler) handleTextDocumentDidSave(ctx context.Context, conn *jsonr
 	}
 
 	if params.Text != nil {
-		err = h.updateFile(params.TextDocument.URI, *params.Text, nil)
+		err = h.updateFile(params.TextDocument.URI, *params.Text, nil, eventTypeSave)
 	} else {
 		err = h.saveFile(params.TextDocument.URI)
 	}
