@@ -20,7 +20,7 @@ func TestLintNoLinter(t *testing.T) {
 		},
 	}
 
-	_, err := h.lint(context.Background(), "file:///foo")
+	_, err := h.lint(context.Background(), "file:///foo", eventTypeChange)
 	if err != nil {
 		t.Fatal("Should not be an error if no linters")
 	}
@@ -35,7 +35,7 @@ func TestLintNoFileMatched(t *testing.T) {
 		},
 	}
 
-	_, err := h.lint(context.Background(), "file:///bar")
+	_, err := h.lint(context.Background(), "file:///bar", eventTypeChange)
 	if err == nil {
 		t.Fatal("Should be an error if no linters")
 	}
@@ -66,7 +66,7 @@ func TestLintFileMatched(t *testing.T) {
 		},
 	}
 
-	uriToDiag, err := h.lint(context.Background(), uri)
+	uriToDiag, err := h.lint(context.Background(), uri, eventTypeChange)
 	d := uriToDiag[uri]
 	if err != nil {
 		t.Fatal(err)
@@ -106,14 +106,14 @@ func TestLintFileMatchedForce(t *testing.T) {
 			},
 		},
 		files: map[DocumentURI]*File{
-			uri: &File{
+			uri: {
 				LanguageID: "vim",
 				Text:       "scriptencoding utf-8\nabnormal!\n",
 			},
 		},
 	}
 
-	uriToDiag, err := h.lint(context.Background(), uri)
+	uriToDiag, err := h.lint(context.Background(), uri, eventTypeChange)
 	d := uriToDiag[uri]
 	if err != nil {
 		t.Fatal(err)
@@ -157,14 +157,14 @@ func TestLintOffsetColumnsZero(t *testing.T) {
 			},
 		},
 		files: map[DocumentURI]*File{
-			uri: &File{
+			uri: {
 				LanguageID: "vim",
 				Text:       "scriptencoding utf-8\nabnormal!\n",
 			},
 		},
 	}
 
-	uriToDiag, err := h.lint(context.Background(), uri)
+	uriToDiag, err := h.lint(context.Background(), uri, eventTypeChange)
 	d := uriToDiag[uri]
 	if err != nil {
 		t.Fatal(err)
@@ -198,14 +198,14 @@ func TestLintOffsetColumnsNoOffset(t *testing.T) {
 			},
 		},
 		files: map[DocumentURI]*File{
-			uri: &File{
+			uri: {
 				LanguageID: "vim",
 				Text:       "scriptencoding utf-8\nabnormal!\n",
 			},
 		},
 	}
 
-	uriToDiag, err := h.lint(context.Background(), uri)
+	uriToDiag, err := h.lint(context.Background(), uri, eventTypeChange)
 	d := uriToDiag[uri]
 	if err != nil {
 		t.Fatal(err)
@@ -240,14 +240,14 @@ func TestLintOffsetColumnsNonZero(t *testing.T) {
 			},
 		},
 		files: map[DocumentURI]*File{
-			uri: &File{
+			uri: {
 				LanguageID: "vim",
 				Text:       "scriptencoding utf-8\nabnormal!\n",
 			},
 		},
 	}
 
-	uriToDiag, err := h.lint(context.Background(), uri)
+	uriToDiag, err := h.lint(context.Background(), uri, eventTypeChange)
 	d := uriToDiag[uri]
 	if err != nil {
 		t.Fatal(err)
@@ -285,14 +285,14 @@ func TestLintCategoryMap(t *testing.T) {
 			},
 		},
 		files: map[DocumentURI]*File{
-			uri: &File{
+			uri: {
 				LanguageID: "vim",
 				Text:       "scriptencoding utf-8\nabnormal!\n",
 			},
 		},
 	}
 
-	uriToDiag, err := h.lint(context.Background(), uri)
+	uriToDiag, err := h.lint(context.Background(), uri, eventTypeChange)
 	d := uriToDiag[uri]
 	if err != nil {
 		t.Fatal(err)
@@ -326,14 +326,14 @@ func TestLintRequireRootMarker(t *testing.T) {
 			},
 		},
 		files: map[DocumentURI]*File{
-			uri: &File{
+			uri: {
 				LanguageID: "vim",
 				Text:       "scriptencoding utf-8\nabnormal!\n",
 			},
 		},
 	}
 
-	d, err := h.lint(context.Background(), uri)
+	d, err := h.lint(context.Background(), uri, eventTypeChange)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -376,7 +376,7 @@ func TestLintMultipleFiles(t *testing.T) {
 		lastPublishedURIs: make(map[string]map[DocumentURI]struct{}),
 	}
 
-	d, err := h.lint(context.Background(), uri)
+	d, err := h.lint(context.Background(), uri, eventTypeChange)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -397,7 +397,7 @@ func TestLintMultipleFiles(t *testing.T) {
 	}
 
 	h.configs["vim"][0].LintCommand = `echo ` + file + `:2:1:First file only!`
-	d, err = h.lint(context.Background(), uri)
+	d, err = h.lint(context.Background(), uri, eventTypeChange)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -429,7 +429,7 @@ func TestLintMultipleFilesWithCancel(t *testing.T) {
 		configs: map[string][]Language{
 			"vim": {
 				{
-					LintCommand:        `echo ` + file + `:2:1:First file! && echo ` + file2 + `:1:2:Second file! && echo ` + file2 + `:Empty l and c!` ,
+					LintCommand:        `echo ` + file + `:2:1:First file! && echo ` + file2 + `:1:2:Second file! && echo ` + file2 + `:Empty l and c!`,
 					LintFormats:        []string{"%f:%l:%c:%m", "%f:%m"},
 					LintIgnoreExitCode: true,
 					LintWorkspace:      true,
@@ -449,7 +449,7 @@ func TestLintMultipleFilesWithCancel(t *testing.T) {
 		lastPublishedURIs: make(map[string]map[DocumentURI]struct{}),
 	}
 
-	d, err := h.lint(context.Background(), uri)
+	d, err := h.lint(context.Background(), uri, eventTypeChange)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -481,7 +481,7 @@ func TestLintMultipleFilesWithCancel(t *testing.T) {
 	h.configs["vim"][0].LintCommand = `touch ` + startedFlagPath + ` && sleep 1000000 && echo ` + file + `:2:1:First file only!`
 	ctx, cancel := context.WithCancel(context.Background())
 	go func() {
-		h.lint(ctx, uri)
+		h.lint(ctx, uri, eventTypeChange)
 	}()
 	for true {
 		if _, err := os.Stat(startedFlagPath); errors.Is(err, os.ErrNotExist) {
@@ -492,7 +492,7 @@ func TestLintMultipleFilesWithCancel(t *testing.T) {
 	}
 	cancel()
 	h.configs["vim"][0].LintCommand = `echo ` + file + `:2:1:First file only!`
-	d, err = h.lint(context.Background(), uri)
+	d, err = h.lint(context.Background(), uri, eventTypeChange)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -535,7 +535,7 @@ func TestLintNoDiagnostics(t *testing.T) {
 		},
 	}
 
-	uriToDiag, err := h.lint(context.Background(), uri)
+	uriToDiag, err := h.lint(context.Background(), uri, eventTypeChange)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -548,6 +548,63 @@ func TestLintNoDiagnostics(t *testing.T) {
 	}
 }
 
+func TestLintOnSave(t *testing.T) {
+	base, _ := os.Getwd()
+	file := filepath.Join(base, "foo")
+	uri := toURI(file)
+
+	h := &langHandler{
+		logger:   log.New(log.Writer(), "", log.LstdFlags),
+		rootPath: base,
+		configs: map[string][]Language{
+			"vim": {
+				{
+					LintCommand:        `echo ` + file + `:2:No it is normal!`,
+					LintIgnoreExitCode: true,
+					LintStdin:          true,
+					LintOnSave:         true,
+				},
+			},
+		},
+		files: map[DocumentURI]*File{
+			uri: {
+				LanguageID: "vim",
+				Text:       "scriptencoding utf-8\nabnormal!\n",
+			},
+		},
+	}
+
+	uriToDiag, err := h.lint(context.Background(), uri, eventTypeChange)
+	if err != nil {
+		t.Fatal(err)
+	}
+	d := uriToDiag[uri]
+	if len(d) != 0 {
+		t.Fatal("diagnostics should be empty", d)
+	}
+
+	uriToDiag, err = h.lint(context.Background(), uri, eventTypeSave)
+	if err != nil {
+		t.Fatal(err)
+	}
+	d = uriToDiag[uri]
+	if len(d) != 1 {
+		t.Fatal("diagnostics should be only one", d)
+	}
+	if d[0].Range.Start.Line != 1 {
+		t.Fatalf("range.start.line should be %v but got: %v", 1, d[0].Range.Start.Line)
+	}
+	if d[0].Range.Start.Character != 0 {
+		t.Fatalf("range.start.character should be %v but got: %v", 0, d[0].Range.Start.Character)
+	}
+	if d[0].Severity != 1 {
+		t.Fatalf("severity should be %v but got: %v", 0, d[0].Severity)
+	}
+	if strings.TrimSpace(d[0].Message) != "No it is normal!" {
+		t.Fatalf("message should be %q but got: %q", "No it is normal!", strings.TrimSpace(d[0].Message))
+	}
+}
+
 func TestHover(t *testing.T) {
 	base, _ := os.Getwd()
 	file := filepath.Join(base, "foo")
